<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();
$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array
$case_stmt->close();



// -------------------------------------------------------------------------
// Query documents and group them by month (e.g. "2025-02").
// -------------------------------------------------------------------------

// Helper function to format file sizes
function formatSizeUnits($bytes)
{
    if ($bytes >= 1073741824) {
        $bytes = number_format($bytes / 1073741824, 2) . ' GB';
    } elseif ($bytes >= 1048576) {
        $bytes = number_format($bytes / 1048576, 2) . ' MB';
    } elseif ($bytes >= 1024) {
        $bytes = number_format($bytes / 1024, 2) . ' KB';
    } elseif ($bytes > 1) {
        $bytes = $bytes . ' bytes';
    } elseif ($bytes == 1) {
        $bytes = $bytes . ' byte';
    } else {
        $bytes = '0 bytes';
    }
    return $bytes;
}

$groupedDocs = [];

$queryDocs = "SELECT 
                  d.id AS DocumentID,
                  d.type,
                  d.filename,
                  d.`file-size` AS size,
                  d.`created-when` AS `When`,
                  a.nme AS `By`
              FROM client_documents d
              LEFT JOIN account_users a ON d.`created-by` = a.id
              WHERE d.cid = ?
              ORDER BY d.`created-when` ASC";

if ($stmtDocs = $conn->prepare($queryDocs)) {
    $stmtDocs->bind_param("i", $id);
    $stmtDocs->execute();
    $resultDocs = $stmtDocs->get_result();

    while ($row = $resultDocs->fetch_assoc()) {
        // Format file size
        $row['size'] = formatSizeUnits($row['size']);

        // Create keys for grouping by month
        $monthKey     = !empty($row['When']) ? date("Y-m", strtotime($row['When'])) : "N/A";
        $monthDisplay = !empty($row['When']) ? date("F Y", strtotime($row['When'])) : "N/A";

        // Get file extension and choose an icon
        $row['extn'] = strtolower(pathinfo($row['filename'], PATHINFO_EXTENSION));
        switch ($row['extn']) {
            case 'jpeg':
            case 'jpg':
            case 'png':
                $img = "fa fa-file-image-o text-primary";
                break;
            case 'doc':
            case 'docx':
                $img = "fa fa-file-word-o text-info";
                break;
            case 'xls':
            case 'xlsx':
            case 'pdf':
                $img = "fa fa-file-pdf-o text-danger";
                break;
            default:
                $img = "fa fa-file-o text-dark";
                break;
        }

        // Build document info array with both view and download links.
        $doc = [
            'name'         => $row['filename'],
            'exn'          => $row['extn'],
            'size'         => $row['size'],
            'img'          => $img,
            'viewLink'     => "../document-view/" . $row['DocumentID'] . "/",
            'downloadLink' => "../document-download/" . $row['DocumentID'] . "/",
            'CreatedBy'    => $row['By'],
            'created_when' => !empty($row['When']) ? date("d-m-Y H:ia", strtotime($row['When'])) : "N/A",
        ];

        // Group the document under its month
        $groupedDocs[$monthKey]['monthDisplay'] = $monthDisplay;
        $groupedDocs[$monthKey]['docs'][] = $doc;
    }
    $stmtDocs->close();
}

// Sort the months in descending order (latest month first)
if (!empty($groupedDocs)) {
    krsort($groupedDocs);
}

// Determine the selected month from GET parameters
$selectedMonth = isset($_GET['month']) ? $_GET['month'] : '';
?>
<!DOCTYPE html>
<html>

<head>
    <!-- [Bootstrap, jQuery, Popper, Bootstrap JS, and other includes] -->
    <title>Subfolders | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
    <style>
        /* CSS for two-panel layout */
        .container-fluid {
            display: flex;
        }

        .subfolders {
            flex: 1;
            padding: 10px;
            border-right: 1px solid #ccc;
        }

        .documents {
            flex: 2;
            padding: 10px;
        }

        .btn-group {
            margin-top: 5px;
        }
    </style>
</head>
<!-- ... previous HTML and PHP code ... -->

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <div class="row">
                        <div class="subfolders">
                            <h2>Months</h2>
                            <ul class="list-group list-group-flush">
                                <?php
                                if (!empty($groupedDocs)) {
                                    foreach ($groupedDocs as $monthKey => $monthData) {
                                        echo "<li class='list-group-item'>
                                                <a href='?client_id=" . urlencode($id)
                                            . "&month=" . urlencode($monthKey) . "'>"
                                            . htmlspecialchars($monthData['monthDisplay']) .
                                            "</a></li>";
                                    }
                                } else {
                                    echo "<li class='list-group-item'>No documents available</li>";
                                }
                                ?>
                            </ul>
                        </div>
                        <div class="documents">
                            <h2>Documents</h2>
                            <?php
                            if ($selectedMonth && isset($groupedDocs[$selectedMonth])) {
                                $monthData = $groupedDocs[$selectedMonth];
                                echo "<h3 style='font-size:18px; color:grey; margin-top:20px; margin-left:10px;'>" . htmlspecialchars($monthData['monthDisplay']) . "</h3>";
                                echo "<ul class='list-group list-group-flush'>";
                                foreach ($monthData['docs'] as $doc) {
                                    echo "<li class='list-group-item'>";
                                    echo "<i class='{$doc['img']}'></i> ";
                                    echo "<strong>" . htmlspecialchars($doc['name']) . "</strong> ";
                                    echo "(" . htmlspecialchars($doc['size']) . ")<br>";
                                    echo "<small>Created by: " . htmlspecialchars($doc['CreatedBy']) . " on " . htmlspecialchars($doc['created_when']) . "</small>";
                                    echo "<br>";
                                    echo "<div class='btn-group'>";
                                    echo "<a href='" . htmlspecialchars($doc['viewLink']) . "' target='_blank' class='btn btn-primary btn-sm'>View</a> ";
                                    echo "<a href='" . htmlspecialchars($doc['downloadLink']) . "' class='btn btn-secondary btn-sm'>Download</a>";
                                    echo "</div>";
                                    echo "</li>";
                                }
                                echo "</ul>";
                            } else {
                                echo "<p>Select a month from the left panel to view documents.</p>";
                            }
                            ?>
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- [Other includes or scripts] -->
</body>

</html>