<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

$case_stmt->close();

// Single query: fetch both 'I' and 'E'
$sql = "SELECT id, name, data
            FROM `client-other-information`
            WHERE cid = ? ";

$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();

// Prepare two arrays to categorize the results
$incomeRows = [];
$expenditureRows = [];

while ($row = $result->fetch_assoc()) {
    // Attempt to uncompress data
    $uncompressedData = @gzuncompress($row['data']);
    if ($uncompressedData !== false) {
        // If gzuncompress succeeded, try JSON decode
        $decoded = json_decode($uncompressedData, true);
        if (json_last_error() === JSON_ERROR_NONE) {
            $row['data'] = $decoded;
        } else {
            // Fallback to unserialize if JSON decode fails
            $row['data'] = unserialize($uncompressedData);
        }
    } else {
        // Fallback: it was not compressed; try JSON decode
        $decoded = json_decode($row['data'], true);
        if (json_last_error() === JSON_ERROR_NONE) {
            $row['data'] = $decoded;
        } else {
            // Fallback to unserialize if JSON decode fails
            $row['data'] = unserialize($row['data']);
        }
    }

    // Now push $row into income[] or expenditure[] based on its 'type'
    if ($row['name'] === 'INCOME') {
        $incomeRows[] = $row;
    } elseif ($row['name'] === 'EXPENDITURE') {
        $expenditureRows[] = $row;
    }
}

$stmt->close();



// Calculate total Income by looping through each sub-entry
$totalIncome = 0.0;
foreach ($incomeRows as $inc) {
    if (isset($inc['data']) && is_array($inc['data'])) {
        foreach ($inc['data'] as $entry) {
            // Remove any commas before converting to a float
            $amount = floatval(str_replace(',', '', $entry['Amount']));
            $totalIncome += $amount;
        }
    }
}

// Calculate total Expenditure similarly
$totalExpenditure = 0.0;
foreach ($expenditureRows as $exp) {
    if (isset($exp['data']) && is_array($exp['data'])) {
        foreach ($exp['data'] as $entry) {
            $amount = floatval(str_replace(',', '', $entry['Amount']));
            $totalExpenditure += $amount;
        }
    }
}

// Calculate Disposable Income (DI)
$disposableIncome = $totalIncome - $totalExpenditure;

?>

<!DOCTYPE html>
<html>

<head>
    <!-- [Bootstrap, jQuery, Popper, Bootstrap JS, and other includes] -->
    <title>Income and Expenditure | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<style>
    /* In your CSS file or style section */
    .green-text {
        color: darkgreen;
    }

    .red-text {
        color: darkred;
    }

    .highlight-green {
        background-color: rgb(52, 194, 142, 0.2);
        /* light yellow highlight */
    }

    .highlight-red {
        background-color: rgb(245, 105, 105, 0.2);
    }
</style>

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-md-5">
                            <!-- This is the left side for Income -->
                            <h3 class="green-text">Income £<?php echo number_format($totalIncome, 2); ?></h3>


                            <table class="table table-bordered border-success mb-0" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <thead class="table-light" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                    <tr speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                        <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Name</th>
                                        <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Amount</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($incomeRows as $inc): ?>
                                        <?php if (isset($inc['data']) && is_array($inc['data'])): ?>
                                            <?php foreach ($inc['data'] as $entry): ?>
                                                <?php
                                                // Remove commas and convert to float
                                                $amount = floatval(str_replace(',', '', $entry['Amount']));
                                                // If amount is non-zero, add the 'highlight' class
                                                $highlightClass = ($amount > 0) ? 'highlight-green' : '';
                                                ?>
                                                <tr class="income-row <?php echo $highlightClass; ?>" data-id="<?php echo $inc['id']; ?>">
                                                    <td><?php echo htmlspecialchars($entry['Name']); ?></td>
                                                    <td><?php echo number_format($amount, 2); ?></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <div class="col-md-5">
                            <!-- This is the right side for Expenditure -->
                            <h3 class="red-text">Expenditure £<?php echo number_format($totalExpenditure, 2); ?></h3>

                            <table class="table table-bordered border-danger mb-0" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <thead class="table-light" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                    <tr speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                        <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Name</th>
                                        <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Amount</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($expenditureRows as $exp): ?>
                                        <?php if (isset($exp['data']) && is_array($exp['data'])): ?>
                                            <?php foreach ($exp['data'] as $entry): ?>
                                                <?php
                                                $amount = floatval(str_replace(',', '', $entry['Amount']));
                                                $highlightClass = ($amount > 0) ? 'highlight-red' : '';
                                                ?>
                                                <tr class="expense-row <?php echo $highlightClass; ?>" data-id="<?php echo $exp['id']; ?>">
                                                    <td><?php echo htmlspecialchars($entry['Name']); ?></td>
                                                    <td><?php echo number_format($amount, 2); ?></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <div class="col-md-2">
                            <?php $disposableIncome = $totalIncome - $totalExpenditure; ?>
                            <div class="card">
                                <div class="card-body center">
                                    <h3 class="card-title fs-3">DI</h3>
                                    <h4 class="card-text fs-2 <?php echo $disposableIncome < 0 ? 'text-danger' : ''; ?>">
                                        £<?php echo number_format((float)$disposableIncome, 2); ?>
                                    </h4>
                                    <!-- Button for 'Create' -->
                                    <!--<button type="button" class="btn btn-success" data-toggle="modal" data-target="#createEntryModal">-->
                                    <!--    Create-->
                                    <!--</button>-->
                                    <br>
                                    <br>
                                    <!--<a href="Income_Expenditure_export?client_id=<?php echo $id ?>" target="_blank">-->
                                    <!--    <button type="button" class="btn btn-warning">-->
                                    <!--        Export Income and Expenditure-->
                                    <!--    </button>-->
                                    <!--</a>-->
                                </div>
                            </div>
                        </div>


                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Add a modal for editing income and expenditure entries -->
    <div class="modal fade" id="editEntryModal" tabindex="-1" role="dialog" aria-labelledby="editEntryModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editEntryModalLabel">Edit Entry</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <form>
                        <div class="form-group">
                            <label for="entryName">Name</label>
                            <input type="text" class="form-control" id="entryName" required>
                        </div>
                        <div class="form-group">
                            <label for="entryAmount">Amount</label>
                            <input type="number" class="form-control" id="entryAmount" required>
                        </div>
                        <div class="form-group">
                            <label for="entryFrequency">Frequency</label>
                            <select class="form-control" id="entryFrequency" required>
                                <option value="daily">Daily</option>
                                <option value="weekly">Weekly</option>
                                <option value="quarterly">Quarterly</option>
                                <option value="fortnightly">Fortnightly</option>
                                <option value="monthly">Monthly</option>
                                <option value="sixMonthly">Six Monthly</option>
                                <option value="yearly">Yearly</option>
                                <option value="fourWeekly">Four Weekly</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="entryDate">Date Each Month</label>
                            <input type="text" class="form-control" id="entryDate" required>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <!-- Add the "Delete" button inside the modal footer -->
                    <button type="button" class="btn btn-danger" id="deleteEntryButton" data-id="">Delete</button>
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-success" id="saveEntryButton">Save Changes</button>
                </div>
            </div>
        </div>
    </div>


    <!-- Modal -->
    <div class="modal fade" id="createEntryModal" tabindex="-1" role="dialog" aria-labelledby="createEntryModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="createEntryModalLabel">Create I&E Entry</h5>
                </div>
                <div class="modal-body">
                    <!-- Add your form elements here for creating entries -->
                    <form>
                        <div class="form-group">
                            <label for="entryType">I&E Type</label>
                            <select class="form-control" id="entryType" required>
                                <option value="#">-- Please select --</option>
                                <option value="I">Income</option>
                                <option value="E">Expenditure</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="inputName">Name</label>
                            <input type="text" class="form-control" id="inputName" required>
                        </div>

                        <div class="form-group">
                            <label for="inputAmount">Amount</label>
                            <input type="number" class="form-control" id="inputAmount" required>
                        </div>
                        <div class="form-group">
                            <label for="entrySubtotal">Subtotal</label>
                            <input type="text" class="form-control" id="entrySubtotal" readonly>
                        </div>
                        <div class="form-group">
                            <label for="inputFrequency">Frequency</label>
                            <select class="form-control" id="inputFrequency" required>
                                <option value="#">-- Please select --</option>
                                <option value="daily">Daily</option>
                                <option value="monthly">Monthly</option>
                                <option value="yearly">Yearly</option>
                                <option value="quarterly">Quarterly</option>
                                <option value="sixMonthly">Six Monthly</option>
                                <option value="fortnightly">Fortnightly</option>
                                <option value="weekly">Weekly</option>
                                <option value="four-Weekly">Four Weekly</option>
                            </select>
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-success" id="SaveNew">Save</button>

                </div>
            </div>
        </div>
    </div>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <!-- Include Bootstrap JavaScript -->
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script type="text/javascript">
        // Function to calculate and update subtotal
        function updateSubtotal() {
            const amount = parseFloat(document.getElementById('inputAmount').value);
            const frequency = document.getElementById('inputFrequency').value;
            let subtotal = amount;

            if (frequency === 'daily') {
                subtotal = (amount * 365) / 12;
            } else if (frequency === 'fortnightly') {
                subtotal = (amount * 26) / 12;
            } else if (frequency === 'weekly') {
                subtotal = (amount * 52) / 12;
            } else if (frequency === 'quarterly') {
                subtotal = (amount * 4) / 12;
            } else if (frequency === 'sixMonthly') { // Updated to match the option value
                subtotal = (amount * 2) / 12;
            } else if (frequency === 'yearly') {
                subtotal = amount / 12;
            } else if (frequency === 'fourWeekly') {
                subtotal = (amount * 13) / 12;
            } else if (frequency === 'monthly') {
                subtotal = amount;
            }

            document.getElementById('entrySubtotal').value = subtotal.toFixed(2);
            console.log('Subtotal updated:', subtotal);
        }

        // Event listener for amount change using input event
        document.getElementById('inputAmount').addEventListener('input', updateSubtotal);

        // Event listener for frequency change using change event
        document.getElementById('inputFrequency').addEventListener('change', updateSubtotal);

        // Initialize subtotal calculation
        updateSubtotal();
        console.log('Subtotal initialized');
    </script>
    <script>
        var id = <?php echo json_encode($id); ?>;
    </script>


    <script type="text/javascript">
        // Event listener for the "Save" button in the modal
        document.getElementById('SaveNew').addEventListener('click', submitForm);

        // Function to handle form submission
        function submitForm() {
            const entryType = document.getElementById('entryType').value;
            const inputName = document.getElementById('inputName').value;
            const inputFrequency = document.getElementById('inputFrequency').value;
            const inputAmount = parseFloat(document.getElementById('inputAmount').value);
            const entrySubtotal = parseFloat(document.getElementById('entrySubtotal').value);

            // Send the form data to the PHP script using AJAX
            $.ajax({
                type: 'POST',
                url: '/client/Updates/insert_entry.php',
                data: {
                    id: id, // Include the id here
                    entryType: entryType,
                    entryName: inputName,
                    entryFrequency: inputFrequency,
                    entryAmount: inputAmount,
                    entrySubtotal: entrySubtotal
                },
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        // Data inserted successfully, refresh the page
                        location.reload();
                    } else {
                        // Error occurred, display an error message or handle it as needed
                        alert('Error: ' + response.message);
                    }
                },
                error: function() {
                    // AJAX request failed, display an error message or handle it as needed
                    alert('Error: AJAX request failed');
                }
            });
            console.log('Form submitted');
        }

        // Function to open the edit modal and populate it with data
        function openEditModal(rowId) {
            const modal = $('#editEntryModal');
            // Fetch the data for the selected row using AJAX
            $.ajax({
                type: 'GET',
                url: '/client/Get/get_entry_data.php', // Create a PHP script to fetch entry data by ID
                data: {
                    id: rowId
                },
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        // Populate the modal input fields with the fetched data
                        modal.find('#entryName').val(response.data.name);
                        modal.find('#entryAmount').val(response.data.amount);
                        modal.find('#entryFrequency').val(response.data.often);
                        modal.find('#entryDate').val(response.data.DateEachMonth);
                        // Add a data-id attribute to the Save button to identify the entry being edited
                        modal.find('#saveEntryButton').attr('data-id', rowId);
                        modal.find('#deleteEntryButton').attr('data-id', rowId); // Set the data-id for the Delete button
                        modal.modal('show');
                    } else {
                        alert('Error fetching data');
                    }
                },
                error: function() {
                    alert('Error: AJAX request failed');
                }
            });
            console.log('Edit modal opened');
        }

        // Attach click event handlers to the income and expenditure rows
        $('.income-row').click(function() {
            const rowId = $(this).data('id');
            openEditModal(rowId);
        });

        $('.expense-row').click(function() {
            const rowId = $(this).data('id');
            openEditModal(rowId);
        });

        // Add a click event handler to the Save button in the edit modal
        $('#saveEntryButton').click(function() {
            const rowId = $(this).data('id');
            // Get the updated data from the modal input fields
            const updatedName = $('#entryName').val();
            const updatedAmount = $('#entryAmount').val();
            const updatedFrequency = $('#entryFrequency').val();
            const updatedentryDate = $('#entryDate').val();
            console.log(updatedAmount);

            // Send the updated data to the server using AJAX for updating the entry
            $.ajax({
                type: 'POST',
                url: '/client/Updates/update_entry.php', // Create a PHP script to update the entry by ID
                data: {
                    id: rowId,
                    name: updatedName,
                    amount: updatedAmount,
                    frequency: updatedFrequency,
                    DateEachMonth: updatedentryDate
                },
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        // Entry updated successfully, close the modal and refresh the page
                        $('#editEntryModal').modal('hide');
                        location.reload();
                    } else {
                        alert
                            ('Error updating entry');
                    }
                },
                error: function() {
                    alert('Error: AJAX request failed');
                }
            });
            console.log('Entry updated');
        });

        // Add a click event handler to the "Delete" button in the edit modal
        $('#deleteEntryButton').click(function() {
            const rowId = $(this).data('id'); // Retrieve the 'data-id' attribute from the button
            const confirmDelete = confirm('Are you sure you want to delete this entry?');

            if (confirmDelete) {
                // Make an AJAX request to delete the entry
                $.ajax({
                    type: 'POST',
                    url: '/client/Updates/delete_entry.php', // Create this PHP script to handle deletion
                    data: {
                        id: rowId
                    },
                    dataType: 'json',
                    success: function(response) {
                        if (response.success) {
                            // Entry deleted successfully, close the modal
                            $('#editEntryModal').modal('hide');
                            location.reload();
                            // Remove the corresponding row from the table (you may need to identify the row)
                            // Example: $(`#row_${rowId}`).remove();
                        } else {
                            alert('Error deleting entry');
                        }
                    },
                    error: function() {
                        alert('Error: AJAX request failed');
                    }
                });
                console.log('Entry deleted');
            }
        });
    </script>

    <script type="text/javascript">
        // Script to calculate totals and update the spans
        document.getElementById('totalIncome').textContent = '£' + parseFloat(<?php echo $totalIncome; ?>).toFixed(2);
        document.getElementById('totalExpenditure').textContent = '£' + parseFloat(<?php echo $totalExpenditure; ?>).toFixed(2);
        console.log('Total income and expenditure calculated');
    </script>

</body>

</html>