<?php
session_start();
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

include_once 'config_current.php';

// Initialize default start/end dates
$start_date = date('Y-m-d');
$end_date   = date('Y-m-d');

// If we have a report_id, determine which query to run
if (isset($_GET['report_id'])) {
    // Sanitize the report id
    $reportId = $conn->real_escape_string($_GET['report_id']);

    // If the form was submitted, override default dates
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $start_date = !empty($_POST['start']) ? $_POST['start'] : $start_date;
        $end_date   = !empty($_POST['end'])   ? $_POST['end']   : $end_date;
    }

    // Convert to datetime ranges
    $startParam = date('Y-m-d 00:00:00', strtotime($start_date));
    $endParam   = date('Y-m-d 23:59:59', strtotime($end_date));

    // We'll store our final SQL in $dynamicSql
    $dynamicSql = "";
    // For better security, let's build a parameter array
    $bindParams = []; // We'll bind these in prepared statements

    switch ($reportId) {
        // ─────────────────────────────────────────────────────────────
        // Custom case: Report '12' (e.g. Back Book – Agents)
        // Filter by cc-advisor and nxt-py-dte range
        // ─────────────────────────────────────────────────────────────
        case '12':
            // Suppose '12' maps to advisorId=101
            $advisorId = 101;
            $dynamicSql = "
                SELECT 
                    Core.id AS `id`,
                    Core.other_id AS `other-id`,
                    Core.`forename-1` AS `forename-1`,
                    Core.`surname-1`  AS `surname-1`,
                    Core.`malePhone-1` AS `malePhone-1`,
                    Core.`emlAddress-1` AS `emlAddress-1`,
                    Core.`nxt-py-dte`   AS `nxt-py-dte`
                FROM client_core AS Core
                WHERE Core.`cc-advisor` = ?
                  AND Core.`nxt-py-dte` BETWEEN ? AND ?
                ORDER BY Core.`nxt-py-dte` ASC
            ";
            // Fill our $bindParams in the correct order
            $bindParams = [$advisorId, $startParam, $endParam];
            break;

        // ─────────────────────────────────────────────────────────────
        // Custom case: Report '24' (Payment Report – Paid)
        // Filter by payment_status=Paid and nxt-py-dte range
        // ─────────────────────────────────────────────────────────────
        case '24':
            $status = 'Paid';
            $dynamicSql = "
                SELECT 
                    Core.id AS `id`,
                    Core.other_id AS `other-id`,
                    Core.`forename-1` AS `forename-1`,
                    Core.`surname-1`  AS `surname-1`,
                    Core.`malePhone-1` AS `malePhone-1`,
                    Core.`emlAddress-1` AS `emlAddress-1`,
                    Core.`nxt-py-dte`   AS `nxt-py-dte`
                FROM client_core AS Core
                WHERE Core.`payment_status` = ?
                  AND Core.`nxt-py-dte` BETWEEN ? AND ?
                ORDER BY Core.`nxt-py-dte` DESC
            ";
            $bindParams = [$status, $startParam, $endParam];
            break;

        // ─────────────────────────────────────────────────────────────
        // Default case: use report_adhocs
        // Force fixed columns, but let the WHERE come from the DB
        // ─────────────────────────────────────────────────────────────
        default:
            $sql = "SELECT * FROM client_core WHERE id = ? LIMIT 1";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param('s', $reportId);
            $stmt->execute();
            $reportResult = $stmt->get_result();

            if ($reportResult && $reportResult->num_rows > 0) {
                $report = $reportResult->fetch_assoc();
                $whereClause = $report['where_from'];

                // Replace placeholders with ? for prepared statements
                // We assume there's exactly two placeholders: [start] and [end]
                // If your DB has more placeholders, adapt accordingly.
                $whereClause = str_replace("[start]", "?", $whereClause);
                $whereClause = str_replace("[end]",   "?", $whereClause);

                // Force the fixed column list:
                $selectedColumns = "`id`, `other-id`, `forename-1`, `surname-1`, `malePhone-1`, `emlAddress-1`, `nxt-py-dte`";
                $tableName = $report['table_name'];

                $dynamicSql = "SELECT $selectedColumns FROM $tableName WHERE $whereClause";

                // Prepare the parameter array for these placeholders
                // The order in $whereClause must match the order of placeholders
                $bindParams = [$startParam, $endParam];
            } else {
                echo "<p>Report not found.</p>";
            }
            break;
    } // end switch

    // ─────────────────────────────────────────────────────────────
    // Execute the SQL if we have one
    // ─────────────────────────────────────────────────────────────
    if (!empty($dynamicSql)) {
        // Debug: uncomment the line below to see the final SQL + param structure
        // echo "<pre>SQL: $dynamicSql\nParams: " . print_r($bindParams, true) . "</pre>";

        // Prepare the statement
        $stmt = $conn->prepare($dynamicSql);
        if (!$stmt) {
            echo "<p>Error preparing statement: " . $conn->error . "</p>";
        } else {
            // Dynamically bind params
            // We need a string for each param type. If all are strings/dates, do 'sss...'
            // If 'id' is integer, adapt accordingly. For simplicity, let's assume strings:
            $types = str_repeat('s', count($bindParams)); // e.g. 'sss' for 3 params
            $stmt->bind_param($types, ...$bindParams);

            if (!$stmt->execute()) {
                echo "<p>Error executing query: " . $stmt->error . "</p>";
            } else {
                $result = $stmt->get_result();
            }
        }
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Display Report</title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <?php include 'layouts/body.php'; ?>
    <div id="layout-wrapper">
        <?php include 'layouts/menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    
                    <!-- Filter Form -->
                    <form method="post">
                        <label for="start">Start date:</label>
                        <input type="date" id="start" name="start" value="<?php echo $start_date; ?>">
                        
                        <label for="end">End date:</label>
                        <input type="date" id="end" name="end" value="<?php echo $end_date; ?>">
                        
                        <input type="submit" class="btn btn-primary waves-effect waves-light" value="Filter">
                    </form>

                    <!-- Export Form -->
                    <form method="post" action="export_to_excel.php">
                        <input type="hidden" name="dynamic_sql" value="<?php echo isset($dynamicSql) ? htmlspecialchars($dynamicSql) : ''; ?>">
                        <input type="submit" class="btn btn-warning waves-effect waves-light" name="export_to_excel" value="Export to Excel">
                    </form>

                    <!-- Table Display -->
                    <div class="responsive-table-container">
                        <?php
                        // Only render table if we have a valid $result
                        if (!empty($dynamicSql) && isset($result) && $result) {
                            if ($result->num_rows > 0) {
                                echo "<table>";
                                // Fixed headers for the specified columns
                                echo "<tr>";
                                    echo "<th>id</th>";
                                    echo "<th>other-id</th>";
                                    echo "<th>forename-1</th>";
                                    echo "<th>surname-1</th>";
                                    echo "<th>malePhone-1</th>";
                                    echo "<th>emlAddress-1</th>";
                                    echo "<th>nxt-py-dte</th>";
                                echo "</tr>";
                                
                                // Data rows (output only the specified columns)
                                while ($row = $result->fetch_assoc()) {
                                    echo "<tr>";
                                        echo "<td>" . htmlspecialchars($row['id'] ?? '') . "</td>";
                                        echo "<td>" . htmlspecialchars($row['other-id'] ?? '') . "</td>";
                                        echo "<td>" . htmlspecialchars($row['forename-1'] ?? '') . "</td>";
                                        echo "<td>" . htmlspecialchars($row['surname-1'] ?? '') . "</td>";
                                        echo "<td>" . htmlspecialchars($row['malePhone-1'] ?? '') . "</td>";
                                        echo "<td>" . htmlspecialchars($row['emlAddress-1'] ?? '') . "</td>";
                                        echo "<td>" . htmlspecialchars($row['nxt-py-dte'] ?? '') . "</td>";
                                    echo "</tr>";
                                }
                                
                                echo "</table>";
                            } else {
                                echo "<p>No results found for this date range.</p>";
                            }
                        }
                        ?>
                    </div>
                    
                </div><!-- end container -->
            </div><!-- end page-content -->
        </div><!-- end main-content -->
    </div><!-- end layout-wrapper -->
</body>
</html>